@@ -7,11 +7,49 @@ from time import sleep
 import requests
 
 
-URL = 'http://loadingproductions.com'
+URL = 'http://api.loadingproductions.com'
 TEST_URL = 'http://127.0.0.1:5000'
 TEST_CLOUD_URL = 'http://3.137.160.113'
 
 
+def ping(url: str):
+    count = 0
+    received = False
+    while not received and count < 10:
+        try:
+            res = requests.get(url)
+            assert res.status_code == 200, f"Url returned status code: {res.status_code}"
+            assert res.json()['connection'] == "successful", "Connection was not successful"
+            received = True
+        except Exception as e:
+            print(e)
+        count += 1
+
+
+def get_commands(url: str):
+    count = 0
+    while count < 10:
+        try:
+            return requests.get(url)
+        except Exception as e:
+            print(e)
+        count += 1
+
+
+def set_command_as_executed(url: str, command_id):
+    count = 0
+    sent = False
+    while not sent and count < 10:
+        try:
+            res = requests.patch(url + f'/command/{command_id}', data={'executed': True})
+            if res.status_code != 200:
+                raise Exception("failed to update command as executed [command_id]:", command_id)
+            sent = True
+        except Exception as e:
+            print(e)
+        count += 1
+
+
 def config():
     path = Path.cwd() / Path('config.ini')
     if not path.exists():
@@ -26,13 +64,13 @@ def config():
 
 def fetch_commands(url: str, interval=10, wait=5):
     while True:
-        res = requests.get(url)
+        res = get_commands(url)
+        data = []
         try:
             data = [c for c in res.json() if not c['executed']]
             print(f"FETCHED: {len(data)}")
         except:
-            print("Error: request to api crashed")
-            data = []
+            print(f"[Error] Request to api crashed, response: {res = }")
         if len(data) == 0:
             sleep(wait)
             continue
@@ -79,12 +117,15 @@ def run(url: str, interval=10, wait=5):
         for command in commands:
             admin.command_list.append(command['code'])
             command['executed'] = True
-            res = requests.patch(url + f'/command/{command["id"]}', data={'executed': True})
-            if res.status_code != 200:
-                raise Exception("failed to update command to executed = True:", command)
+            set_command_as_executed(url, command['id'])
         admin.execute()
 
 
+def executable():
+    ping(URL)
+    run(URL, interval=10, wait=5)
+
+
 def main():
     print("[1] Run driver with official API")
     print("[2] Test driver with local API")
@@ -101,19 +142,13 @@ def main():
         response = input("What would you like to run? ")
 
     if response == '1':
-        res = requests.get(URL + '/ping')
-        assert res.status_code == 200, f"Url returned status code: {res.status_code}"
-        assert res.json()['connection'] == "successful"
+        ping(URL + '/ping')
         run(URL, interval=10, wait=5)
     elif response == '2':
-        res = requests.get(TEST_URL + '/ping')
-        assert res.status_code == 200, f"Url returned status code: {res.status_code}"
-        assert res.json()['connection'] == "successful"
+        ping(TEST_URL + '/ping')
         run(TEST_URL, interval=10, wait=5)
     elif response == '3':
-        res = requests.get(TEST_CLOUD_URL + '/ping')
-        assert res.status_code == 200, f"Url returned status code: {res.status_code}"
-        assert res.json()['connection'] == "successful"
+        ping(TEST_CLOUD_URL + '/ping')
         run(TEST_CLOUD_URL, interval=10, wait=5)
     elif response == '4':
         presentation()
